@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function, division
+
 import warnings
 
 import matplotlib.axes as maxes
@@ -23,38 +25,43 @@ class Colorbar(object):
         self._parameters = parent._parameters
 
         self._base_settings = {}
-        self._label_fontproperties = FontProperties()
+        self._ticklabel_fontproperties = FontProperties()
+        self._axislabel_fontproperties = FontProperties()
 
     @auto_refresh
-    def show(self, location='right', width=0.2, pad=0.05, ticks=None, labels=True, box=None, box_orientation='vertical'):
+    def show(self, location='right', width=0.2, pad=0.05, ticks=None, labels=True, box=None, box_orientation='vertical', axis_label_text=None, axis_label_rotation=None, axis_label_pad=5):
         '''
         Show a colorbar on the side of the image.
 
-        Optional Keyword Arguments:
+        Parameters
+        ----------
 
-            *location*: [ string ]
-                Where to place the colorbar. Should be one of 'left', 'right', 'top', 'bottom'.
+        location : str, optional
+            Where to place the colorbar. Should be one of 'left', 'right', 'top', 'bottom'.
 
-            *width*: [ float ]
-                The width of the colorbar relative to the canvas size.
+        width : float, optional
+            The width of the colorbar relative to the canvas size.
 
-            *pad*: [ float ]
-                The spacing between the colorbar and the image relative to the canvas size.
+        pad : float, optional
+            The spacing between the colorbar and the image relative to the canvas size.
 
-            *ticks*: [ None or list ]
-                The position of the ticks on the colorbar.
+        ticks : list, optional
+            The position of the ticks on the colorbar.
 
-            *labels*: [ True or False ]
-                Whether to show numerical labels.
+        labels : bool, optional
+            Whether to show numerical labels.
 
-            *box*: [ list ]
-                A custom box within which to place the colorbar. This should
-                be in the form [xmin, ymin, dx, dy] and be in relative figure
-                units. This overrides the location argument.
+        box : list, optional
+            A custom box within which to place the colorbar. This should
+            be in the form [xmin, ymin, dx, dy] and be in relative figure
+            units. This overrides the location argument.
 
-            *box_orientation* [ str ]
-                The orientation of the colorbar within the box. Can be
-                'horizontal' or 'vertical'
+        box_orientation str, optional
+            The orientation of the colorbar within the box. Can be
+            'horizontal' or 'vertical'
+
+        axis_label_text str, optional
+            Optional text label of the colorbar.
         '''
 
         self._base_settings['location'] = location
@@ -64,6 +71,9 @@ class Colorbar(object):
         self._base_settings['labels'] = labels
         self._base_settings['box'] = box
         self._base_settings['box_orientation'] = box_orientation
+        self._base_settings['axis_label_text'] = axis_label_text
+        self._base_settings['axis_label_rotation'] = axis_label_rotation
+        self._base_settings['axis_label_pad'] = axis_label_pad
 
         if self._parent.image:
 
@@ -103,6 +113,11 @@ class Colorbar(object):
                 orientation = box_orientation
 
             self._colorbar = self._parent._figure.colorbar(self._parent.image, cax=self._colorbar_axes, orientation=orientation, ticks=ticks)
+            if axis_label_text:
+                if axis_label_rotation:
+                    self._colorbar.set_label(axis_label_text, rotation=axis_label_rotation)
+                else:
+                    self._colorbar.set_label(axis_label_text)
 
             if location == 'right':
                 for tick in self._colorbar_axes.yaxis.get_major_ticks():
@@ -110,24 +125,32 @@ class Colorbar(object):
                     tick.tick2On = True
                     tick.label1On = False
                     tick.label2On = labels
+                self._colorbar_axes.yaxis.set_label_position('right')
+                self._colorbar_axes.yaxis.labelpad = axis_label_pad
             elif location == 'top':
                 for tick in self._colorbar_axes.xaxis.get_major_ticks():
                     tick.tick1On = True
                     tick.tick2On = True
                     tick.label1On = False
                     tick.label2On = labels
+                self._colorbar_axes.xaxis.set_label_position('top')
+                self._colorbar_axes.xaxis.labelpad = axis_label_pad
             elif location == 'left':
                 for tick in self._colorbar_axes.yaxis.get_major_ticks():
                     tick.tick1On = True
                     tick.tick2On = True
                     tick.label1On = labels
                     tick.label2On = False
+                self._colorbar_axes.yaxis.set_label_position('left')
+                self._colorbar_axes.yaxis.labelpad = axis_label_pad
             elif location == 'bottom':
                 for tick in self._colorbar_axes.xaxis.get_major_ticks():
                     tick.tick1On = True
                     tick.tick2On = True
                     tick.label1On = labels
                     tick.label2On = False
+                self._colorbar_axes.xaxis.set_label_position('bottom')
+                self._colorbar_axes.xaxis.labelpad = axis_label_pad
 
         else:
 
@@ -152,11 +175,14 @@ class Colorbar(object):
     @auto_refresh
     def set_location(self, location):
         '''
-        Set the location of the colorbar. Should be one of 'left', 'right', 'top', 'bottom'.
+        Set the location of the colorbar.
+        
+        Should be one of 'left', 'right', 'top', 'bottom'.
         '''
         self._base_settings['location'] = location
         self.show(**self._base_settings)
-        self.set_font(fontproperties=self._label_fontproperties)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
 
     @auto_refresh
     def set_width(self, width):
@@ -165,7 +191,8 @@ class Colorbar(object):
         '''
         self._base_settings['width'] = width
         self.show(**self._base_settings)
-        self.set_font(fontproperties=self._label_fontproperties)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
 
     @auto_refresh
     def set_pad(self, pad):
@@ -174,7 +201,8 @@ class Colorbar(object):
         '''
         self._base_settings['pad'] = pad
         self.show(**self._base_settings)
-        self.set_font(fontproperties=self._label_fontproperties)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
 
     @auto_refresh
     def set_ticks(self, ticks):
@@ -183,7 +211,8 @@ class Colorbar(object):
         '''
         self._base_settings['ticks'] = ticks
         self.show(**self._base_settings)
-        self.set_font(fontproperties=self._label_fontproperties)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
 
     @auto_refresh
     def set_labels(self, labels):
@@ -192,20 +221,53 @@ class Colorbar(object):
         '''
         self._base_settings['labels'] = labels
         self.show(**self._base_settings)
-        self.set_font(fontproperties=self._label_fontproperties)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
 
     @auto_refresh
     def set_box(self, box, box_orientation='vertical'):
         '''
-        Set the box within which to place the colorbar. This should be in the
-        form [xmin, ymin, dx, dy] and be in relative figure units. The
-        orientation of the colorbar within the box can be controlled with the
-        box_orientation argument.
+        Set the box within which to place the colorbar.
+        
+        This should be in the form [xmin, ymin, dx, dy] and be in relative
+        figure units. The orientation of the colorbar within the box can be
+        controlled with the box_orientation argument.
         '''
         self._base_settings['box'] = box
         self._base_settings['box_orientation'] = box_orientation
         self.show(**self._base_settings)
-        self.set_font(fontproperties=self._label_fontproperties)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
+
+    @auto_refresh
+    def set_axis_label_text(self, axis_label_text):
+        '''
+        Set the colorbar label text.
+        '''
+        self._base_settings['axis_label_text'] = axis_label_text
+        self.show(**self._base_settings)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
+
+    @auto_refresh
+    def set_axis_label_rotation(self, axis_label_rotation):
+        '''
+        Set the colorbar label rotation.
+        '''
+        self._base_settings['axis_label_rotation'] = axis_label_rotation
+        self.show(**self._base_settings)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
+
+    @auto_refresh
+    def set_axis_label_pad(self, axis_label_pad):
+        '''
+        Set the colorbar label displacement, in points.
+        '''
+        self._base_settings['axis_label_pad'] = axis_label_pad
+        self.show(**self._base_settings)
+        self.set_font(fontproperties=self._ticklabel_fontproperties)
+        self.set_axis_label_font(fontproperties=self._axislabel_fontproperties)
 
     # FONT PROPERTIES
 
@@ -218,49 +280,106 @@ class Colorbar(object):
     @fixdocstring
     def set_font(self, family=None, style=None, variant=None, stretch=None, weight=None, size=None, fontproperties=None):
         '''
-        Set the font of the tick labels
+        Set the font of the tick labels.
 
-        Optional Keyword Arguments:
+        Parameters
+        ----------
 
         common: family, style, variant, stretch, weight, size, fontproperties
 
+        Notes
+        -----
+
         Default values are set by matplotlib or previously set values if
         set_font has already been called. Global default values can be set by
         editing the matplotlibrc file.
         '''
 
         if family:
-            self._label_fontproperties.set_family(family)
+            self._ticklabel_fontproperties.set_family(family)
 
         if style:
-            self._label_fontproperties.set_style(style)
+            self._ticklabel_fontproperties.set_style(style)
 
         if variant:
-            self._label_fontproperties.set_variant(variant)
+            self._ticklabel_fontproperties.set_variant(variant)
 
         if stretch:
-            self._label_fontproperties.set_stretch(stretch)
+            self._ticklabel_fontproperties.set_stretch(stretch)
 
         if weight:
-            self._label_fontproperties.set_weight(weight)
+            self._ticklabel_fontproperties.set_weight(weight)
 
         if size:
-            self._label_fontproperties.set_size(size)
+            self._ticklabel_fontproperties.set_size(size)
 
         if fontproperties:
-            self._label_fontproperties = fontproperties
+            self._ticklabel_fontproperties = fontproperties
 
+        # Update the tick label font properties
         for label in self._colorbar_axes.get_xticklabels():
-            label.set_fontproperties(self._label_fontproperties)
+            label.set_fontproperties(self._ticklabel_fontproperties)
         for label in self._colorbar_axes.get_yticklabels():
-            label.set_fontproperties(self._label_fontproperties)
+            label.set_fontproperties(self._ticklabel_fontproperties)
+
+        # Also update the offset text font properties
+        label = self._colorbar_axes.xaxis.get_offset_text()
+        label.set_fontproperties(self._ticklabel_fontproperties)
+        label = self._colorbar_axes.yaxis.get_offset_text()
+        label.set_fontproperties(self._ticklabel_fontproperties)
+
+    @auto_refresh
+    @fixdocstring
+    def set_axis_label_font(self, family=None, style=None, variant=None, stretch=None, weight=None, size=None, fontproperties=None):
+        '''
+        Set the font of the tick labels.
+
+        Parameters
+        ----------
+
+        common: family, style, variant, stretch, weight, size, fontproperties
+
+        Notes
+        -----
+
+        Default values are set by matplotlib or previously set values if
+        set_font has already been called. Global default values can be set by
+        editing the matplotlibrc file.
+        '''
+
+        if family:
+            self._axislabel_fontproperties.set_family(family)
+
+        if style:
+            self._axislabel_fontproperties.set_style(style)
+
+        if variant:
+            self._axislabel_fontproperties.set_variant(variant)
+
+        if stretch:
+            self._axislabel_fontproperties.set_stretch(stretch)
+
+        if weight:
+            self._axislabel_fontproperties.set_weight(weight)
+
+        if size:
+            self._axislabel_fontproperties.set_size(size)
+
+        if fontproperties:
+            self._axislabel_fontproperties = fontproperties
+
+        # Update the label font properties
+        label = self._colorbar_axes.xaxis.get_label()
+        label.set_fontproperties(self._axislabel_fontproperties)
+        label = self._colorbar_axes.yaxis.get_label()
+        label.set_fontproperties(self._axislabel_fontproperties)
 
     # FRAME PROPERTIES
 
     @auto_refresh
     def set_frame_linewidth(self, linewidth):
         '''
-        Set the linewidth of the colorbar frame, in points
+        Set the linewidth of the colorbar frame, in points.
         '''
         warnings.warn("This method is not functional at this time")
         for key in self._colorbar_axes.spines:
@@ -269,7 +388,7 @@ class Colorbar(object):
     @auto_refresh
     def set_frame_color(self, color):
         '''
-        Set the color of the colorbar frame, in points
+        Set the color of the colorbar frame, in points.
         '''
         warnings.warn("This method is not functional at this time")
         for key in self._colorbar_axes.spines:
