@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function, division
+
 import warnings
 
 import numpy as np
@@ -46,11 +48,11 @@ class Grid(object):
         '''
         Set the grid line spacing in the longitudinal direction
 
-        Required Arguments:
-
-            *xspacing*: [ float | 'tick' ]
-                The spacing in the longitudinal direction. To set the spacing
-                to be the same as the ticks, set this to 'tick'
+        Parameters
+        ----------
+        xspacing : { float, str }
+            The spacing in the longitudinal direction. To set the spacing
+            to be the same as the ticks, set this to 'tick'
         '''
         if xspacing == 'tick':
             self.x_auto_spacing = True
@@ -70,11 +72,11 @@ class Grid(object):
         '''
         Set the grid line spacing in the latitudinal direction
 
-        Required Arguments:
-
-            *yspacing*: [ float | 'tick' ]
-                The spacing in the latitudinal direction. To set the spacing
-                to be the same as the ticks, set this to 'tick'
+        Parameters
+        ----------
+        yspacing : { float, str }
+            The spacing in the latitudinal direction. To set the spacing
+            to be the same as the ticks, set this to 'tick'
         '''
 
         if yspacing == 'tick':
@@ -95,10 +97,10 @@ class Grid(object):
         '''
         Set the color of the grid lines
 
-        Required Arguments:
-
-            *color*: [ string ]
-                The color of the grid lines
+        Parameters
+        ----------
+        color : str
+            The color of the grid lines
         '''
         if self._grid:
             self._grid.set_edgecolor(color)
@@ -110,12 +112,12 @@ class Grid(object):
         '''
         Set the alpha (transparency) of the grid lines
 
-        Required Arguments:
-
-            *alpha*: [ float ]
-                The alpha value of the grid. This should be a floating
-                point value between 0 and 1, where 0 is completely
-                transparent, and 1 is completely opaque.
+        Parameters
+        ----------
+        alpha : float
+            The alpha value of the grid. This should be a floating
+            point value between 0 and 1, where 0 is completely
+            transparent, and 1 is completely opaque.
         '''
         if self._grid:
             self._grid.set_alpha(alpha)
@@ -323,6 +325,13 @@ def plot_grid_y(wcs, grid_x, grid_y, gy, alpha=0.5):
             xpix, ypix = wcs_util.world2pix(wcs, min(grid_x_sorted[-1] + 1., 360.), gy)
             if in_plot(wcs, xpix, ypix):
                 grid_x_sorted = np.hstack([grid_x_sorted, 360.])
+
+    # Check if the first mid-point with coordinates is inside the viewport
+    xpix, ypix = wcs_util.world2pix(wcs, (grid_x_sorted[0] + grid_x_sorted[1]) / 2., gy)
+
+    if not in_plot(wcs, xpix, ypix):
+        grid_x_sorted = np.roll(grid_x_sorted, 1)
+
     # Check that number of grid points is even
     if len(grid_x_sorted) % 2 == 1:
         warnings.warn("Unexpected number of grid points - x grid lines cannot be drawn")
@@ -405,7 +414,9 @@ def in_plot(wcs, x_pix, y_pix):
 
 
 def find_intersections(wcs, coord, spacing):
-    '''Find intersections of a given coordinate with a all axes'''
+    '''
+    Find intersections of a given coordinate with a all axes
+    '''
 
     # Initialize arrays
     x = []
