@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
-import string
+from __future__ import absolute_import, print_function, division, unicode_literals
+
 import warnings
 
 import numpy as np
@@ -73,8 +74,10 @@ class TickLabels(object):
     @auto_refresh
     def set_xformat(self, format):
         '''
-        Set the format of the x-axis tick labels. If the x-axis type is
-        ``longitude`` or ``latitude``, then the options are:
+        Set the format of the x-axis tick labels.
+
+        If the x-axis type is ``longitude`` or ``latitude``, then the options
+        are:
 
             * ``ddd.ddddd`` - decimal degrees, where the number of decimal places can be varied
             * ``hh`` or ``dd`` - hours (or degrees)
@@ -107,8 +110,10 @@ class TickLabels(object):
     @auto_refresh
     def set_yformat(self, format):
         '''
-        Set the format of the y-axis tick labels. If the y-axis type is
-        ``longitude`` or ``latitude``, then the options are:
+        Set the format of the y-axis tick labels.
+
+        If the y-axis type is ``longitude`` or ``latitude``, then the options
+        are:
 
             * ``ddd.ddddd`` - decimal degrees, where the number of decimal places can be varied
             * ``hh`` or ``dd`` - hours (or degrees)
@@ -141,7 +146,9 @@ class TickLabels(object):
     @auto_refresh
     def set_style(self, style):
         """
-        Set the format of the x-axis tick labels. This can be 'colons' or 'plain':
+        Set the format of the x-axis tick labels.
+
+        This can be 'colons' or 'plain':
 
             * 'colons' uses colons as separators, for example 31:41:59.26 +27:18:28.1
             * 'plain' uses letters and symbols as separators, for example 31h41m59.26s +27º18'28.1"
@@ -163,12 +170,16 @@ class TickLabels(object):
     @fixdocstring
     def set_font(self, family=None, style=None, variant=None, stretch=None, weight=None, size=None, fontproperties=None):
         """
-        Set the font of the tick labels
+        Set the font of the tick labels.
 
-        Optional Keyword Arguments:
+        Parameters
+        ----------
 
         common: family, style, variant, stretch, weight, size, fontproperties
 
+        Notes
+        -----
+
         Default values are set by matplotlib or previously set values if
         set_font has already been called. Global default values can be set by
         editing the matplotlibrc file.
@@ -207,7 +218,7 @@ class TickLabels(object):
     @auto_refresh
     def show(self):
         """
-        Show the x- and y-axis tick labels
+        Show the x- and y-axis tick labels.
         """
         self.show_x()
         self.show_y()
@@ -215,7 +226,7 @@ class TickLabels(object):
     @auto_refresh
     def hide(self):
         """
-        Hide the x- and y-axis tick labels
+        Hide the x- and y-axis tick labels.
         """
         self.hide_x()
         self.hide_y()
@@ -223,7 +234,7 @@ class TickLabels(object):
     @auto_refresh
     def show_x(self):
         """
-        Show the x-axis tick labels
+        Show the x-axis tick labels.
         """
 
         for tick in self._ax1.get_xticklabels():
@@ -234,7 +245,7 @@ class TickLabels(object):
     @auto_refresh
     def hide_x(self):
         """
-        Hide the x-axis tick labels
+        Hide the x-axis tick labels.
         """
 
         for tick in self._ax1.get_xticklabels():
@@ -245,7 +256,7 @@ class TickLabels(object):
     @auto_refresh
     def show_y(self):
         """
-        Show the y-axis tick labels
+        Show the y-axis tick labels.
         """
 
         for tick in self._ax1.get_yticklabels():
@@ -256,7 +267,7 @@ class TickLabels(object):
     @auto_refresh
     def hide_y(self):
         """
-        Hide the y-axis tick labels
+        Hide the y-axis tick labels.
         """
 
         for tick in self._ax1.get_yticklabels():
@@ -266,7 +277,9 @@ class TickLabels(object):
 
     @auto_refresh
     def set_xposition(self, position):
-        "Set the position of the x-axis tick labels ('top' or 'bottom')"
+        """
+        Set the position of the x-axis tick labels ('top' or 'bottom')
+        """
         if position == 'bottom':
             fx1 = WCSFormatter(wcs=self._wcs, coord='x')
             self._ax1.xaxis.set_major_formatter(fx1)
@@ -282,7 +295,9 @@ class TickLabels(object):
 
     @auto_refresh
     def set_yposition(self, position):
-        "Set the position of the y-axis tick labels ('left' or 'right')"
+        """
+        Set the position of the y-axis tick labels ('left' or 'right')
+        """
         if position == 'left':
             fy1 = WCSFormatter(wcs=self._wcs, coord='y')
             self._ax1.yaxis.set_major_formatter(fy1)
@@ -326,7 +341,7 @@ class TickLabels(object):
                     sep = (':', ':', '')
 
                 xlabel = xw.tostringlist(format=xaxis.apl_label_form, sep=sep)
-                xlabel = string.join(xlabel, "")
+                xlabel = "".join(xlabel)
 
             else:
 
@@ -349,7 +364,7 @@ class TickLabels(object):
                     sep = (':', ':', '')
 
                 ylabel = yw.tostringlist(format=yaxis.apl_label_form, sep=sep)
-                ylabel = string.join(ylabel, "")
+                ylabel = "".join(ylabel)
 
             else:
 
@@ -369,8 +384,10 @@ class WCSFormatter(mpl.Formatter):
         self.coord = coord
 
     def __call__(self, x, pos=None):
-        'Return the format for tick val x at position pos; pos=None indicated unspecified'
-
+        """
+        Return the format for tick val x at position pos; pos=None indicated
+        unspecified
+        """
         self.coord_type = self._wcs.xaxis_coord_type if self.coord == 'x' else self._wcs.yaxis_coord_type
 
         if self.coord_type in ['longitude', 'latitude']:
@@ -388,7 +405,7 @@ class WCSFormatter(mpl.Formatter):
                 label_style = self.axis.apl_labels_style
 
             if label_style == 'plain_notex':
-                sep = (u'\u00b0', u"'", u'"')
+                sep = ('\u00b0', "'", '"')
                 if hours:
                     sep = ('h', 'm', 's')
             elif label_style == 'colons':
@@ -406,24 +423,30 @@ class WCSFormatter(mpl.Formatter):
                 label = label.tohours()
             label = label.tostringlist(format=self.axis.apl_label_form, sep=sep)
 
-            if self.coord == x or self.axis.apl_tick_positions_world[ipos] > 0:
-                comp_ipos = ipos - 1
-            else:
-                comp_ipos = ipos + 1
+            # Check if neighboring label is similar and if so whether some
+            # elements of the current label are redundant and can be dropped.
+            # This should only be done for sexagesimal coordinates
 
-            if comp_ipos >= 0 and comp_ipos <= len(self.axis.apl_tick_positions_pix) - 1:
+            if len(label) > 1:
 
-                comp_label = self.axis.apl_tick_spacing * self.axis.apl_tick_positions_world[comp_ipos]
-                if hours:
-                    comp_label = comp_label.tohours()
-                comp_label = comp_label.tostringlist(format=self.axis.apl_label_form, sep=sep)
+                if self.coord == x or self.axis.apl_tick_positions_world[ipos] > 0:
+                    comp_ipos = ipos - 1
+                else:
+                    comp_ipos = ipos + 1
 
-                for iter in range(len(label)):
-                    if comp_label[0] == label[0]:
-                        label.pop(0)
-                        comp_label.pop(0)
-                    else:
-                        break
+                if comp_ipos >= 0 and comp_ipos <= len(self.axis.apl_tick_positions_pix) - 1:
+
+                    comp_label = self.axis.apl_tick_spacing * self.axis.apl_tick_positions_world[comp_ipos]
+                    if hours:
+                        comp_label = comp_label.tohours()
+                    comp_label = comp_label.tostringlist(format=self.axis.apl_label_form, sep=sep)
+
+                    for iter in range(len(label)):
+                        if comp_label[0] == label[0]:
+                            label.pop(0)
+                            comp_label.pop(0)
+                        else:
+                            break
 
         else:
 
@@ -432,6 +455,6 @@ class WCSFormatter(mpl.Formatter):
             label = self.axis.apl_label_form % label
 
         if mpl.rcParams['text.usetex']:
-            return "$" + string.join(label, "") + "$"
+            return "$" + "".join(label) + "$"
         else:
-            return string.join(label, "")
+            return "".join(label)
