@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function, division
+
 from matplotlib.contour import ContourSet
 from matplotlib.collections import RegularPolyCollection, \
     PatchCollection, CircleCollection, LineCollection
@@ -45,7 +47,7 @@ class Layers(object):
 
     def list_layers(self):
         '''
-        Print a list of layers to standard output
+        Print a list of layers to standard output.
         '''
 
         layers_list = []
@@ -63,28 +65,28 @@ class Layers(object):
 
         n_layers = len(layers_list)
         if n_layers == 0:
-            print "\n  There are no layers in this figure"
+            print("\n  There are no layers in this figure")
         else:
             if n_layers == 1:
-                print "\n  There is one layer in this figure:\n"
+                print("\n  There is one layer in this figure:\n")
             else:
-                print "\n  There are " + str(n_layers) + \
-                    " layers in this figure:\n"
+                print("\n  There are " + str(n_layers) + \
+                    " layers in this figure:\n")
             for layer in layers_list:
                 if layer['visible']:
-                    print "   -> " + layer['name']
+                    print("   -> " + layer['name'])
                 else:
-                    print "   -> " + layer['name'] + " (hidden)"
+                    print("   -> " + layer['name'] + " (hidden)")
 
     @auto_refresh
     def remove_layer(self, layer, raise_exception=True):
         '''
-        Remove a layer
+        Remove a layer.
 
-        Required Arguments:
-
-            *layer*: [ string ]
-                The name of the layer to remove
+        Parameters
+        ----------
+        layer : str
+            The name of the layer to remove
         '''
 
         if layer in self._layers:
@@ -110,15 +112,15 @@ class Layers(object):
     @auto_refresh
     def hide_layer(self, layer, raise_exception=True):
         '''
-        Hide a layer
+        Hide a layer.
 
         This differs from remove_layer in that if a layer is hidden
         it can be shown again using show_layer.
 
-        Required Arguments:
-
-            *layer*: [ string ]
-                The name of the layer to hide
+        Parameters
+        ----------
+        layer : str
+            The name of the layer to hide
         '''
         if layer in self._layers:
 
@@ -138,14 +140,14 @@ class Layers(object):
     @auto_refresh
     def show_layer(self, layer, raise_exception=True):
         '''
-        Show a layer
+        Show a layer.
 
         This shows a layer previously hidden with hide_layer
 
-        Required Arguments:
-
-            *layer*: [ string ]
-                The name of the layer to show
+        Parameters
+        ----------
+        layer : str
+            The name of the layer to show
         '''
         if layer in self._layers:
 
@@ -163,12 +165,12 @@ class Layers(object):
 
     def get_layer(self, layer, raise_exception=True):
         '''
-        Return a layer object
+        Return a layer object.
 
-        Required Arguments:
-
-            *layer*: [ string ]
-                The name of the layer to return
+        Parameters
+        ----------
+        layer : str
+            The name of the layer to return
         '''
         if layer in self._layers:
             return self._layers[layer]
