@@ -1,13 +1,6 @@
-try:
-    import pyregion
-    pyregion_installed = True
-except:
-    pyregion_installed = False
+from __future__ import absolute_import, print_function, division
 
-
-def _check_pyregion_installed():
-    if not pyregion_installed:
-        raise Exception("The pyregion package is required to load region files")
+from astropy import log
 
 from .decorators import auto_refresh
 
@@ -50,24 +43,23 @@ class Regions:
     @auto_refresh
     def show_regions(self, region_file, layer=False, **kwargs):
         """
-        Overplot regions as specified in the regionsfile
+        Overplot regions as specified in the region file.
 
-        Required Arguments:
-            *region_file*: [ string | pyregion.ShapeList ]
-                Path to a ds9 regions file or a ShapeList already read
-                in by pyregion.
+        Parameters
+        ----------
 
-        Optional Keyword Arguments:
+        region_file: string or pyregion.ShapeList
+            Path to a ds9 regions file or a ShapeList already read
+            in by pyregion.
 
-            *layer*: [ string ]
-                The name of the layer
+        layer: str, optional
+            The name of the layer
 
-        Additional keyword arguments, e.g. zorder, will be passed to the ds9
-        call and onto the patchcollections.
+        kwargs
+            Additional keyword arguments, e.g. zorder, will be passed to the
+            ds9 call and onto the patchcollections.
         """
 
-        _check_pyregion_installed()
-
         PC, TC = ds9(region_file, self._header, **kwargs)
 
         #ffpc = self._ax1.add_collection(PC)
@@ -92,6 +84,11 @@ def ds9(region_file, header, zorder=3, **kwargs):
     zorder - defaults to 3 so that regions are on top of contours
     """
 
+    try:
+        import pyregion
+    except:
+        raise ImportError("The pyregion package is required to load region files")
+
     # read region file
     if isinstance(region_file, basestring):
         rr = pyregion.open(region_file)
@@ -104,10 +101,21 @@ def ds9(region_file, header, zorder=3, **kwargs):
     rrim = rr.as_imagecoord(header)
 
     # pyregion and aplpy both correct for the FITS standard origin=1,1
-    # need to avoid double-correcting
+    # need to avoid double-correcting. Also, only some items in `coord_list`
+    # are pixel coordinates, so which ones should be corrected depends on the
+    # shape.
     for r in rrim:
-        r.coord_list[0] += 1
-        r.coord_list[1] += 1
+        if r.name == 'polygon':
+            correct = range(len(r.coord_list))
+        elif r.name == 'line':
+            correct = range(4)
+        elif r.name in ['rotbox', 'box', 'ellipse', 'annulus', 'circle', 'panda', 'pie', 'epanda', 'text', 'point', 'vector']:
+            correct = range(2)
+        else:
+            log.warn("Unknown region type '{0}' - please report to the developers")
+            correct = range(2)
+        for i in correct:
+            r.coord_list[i] += 1
 
     if 'text_offset' in kwargs:
         text_offset = kwargs['text_offset']
