@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function, division
+
 from distutils import version
 import os
 import warnings
@@ -5,35 +7,9 @@ import warnings
 import tempfile
 import shutil
 
-import pyfits
 import numpy as np
-
-from .logger import logger
-
-try:
-    import Image
-    installed_pil = True
-except:
-    installed_pil = False
-
-try:
-    import montage
-    if not hasattr(montage, 'reproject_hdu'):
-        raise
-    montage_installed = True
-except:
-    montage_installed = False
-
-try:
-    from pyavm import AVM
-    avm_installed = True
-except:
-    avm_installed = False
-
-if montage_installed:
-    if version.LooseVersion(montage.__version__) < version.LooseVersion('0.9.2'):
-        warnings.warn("Python-montage installation is not recent enough (version 0.9.2 or later is required). Disabling Montage-related functionality.")
-        montage_installed = False
+from astropy import log
+from astropy.io import fits
 
 from . import image_util
 from . import math_util
@@ -50,16 +26,16 @@ def _data_stretch(image, vmin=None, vmax=None, pmin=0.25, pmax=99.75, \
         vmin_auto, vmax_auto = auto_v(pmin), auto_v(pmax)
 
     if min_auto:
-        logger.info("vmin = %10.3e (auto)" % vmin_auto)
+        log.info("vmin = %10.3e (auto)" % vmin_auto)
         vmin = vmin_auto
     else:
-        logger.info("vmin = %10.3e" % vmin)
+        log.info("vmin = %10.3e" % vmin)
 
     if max_auto:
-        logger.info("vmax = %10.3e (auto)" % vmax_auto)
+        log.info("vmax = %10.3e (auto)" % vmax_auto)
         vmax = vmax_auto
     else:
-        logger.info("vmax = %10.3e" % vmax)
+        log.info("vmax = %10.3e" % vmax)
 
     image = (image - vmin) / (vmax - vmin)
 
@@ -78,111 +54,84 @@ def make_rgb_image(data, output, indices=(0, 1, 2), \
                    stretch_g='linear', vmid_g=None, exponent_g=2, \
                    vmin_b=None, vmax_b=None, pmin_b=0.25, pmax_b=99.75, \
                    stretch_b='linear', vmid_b=None, exponent_b=2, \
-                   embed_avm_tags=False):
+                   embed_avm_tags=True):
     '''
-    Make an RGB image from a FITS RGB cube or from three FITS files
+    Make an RGB image from a FITS RGB cube or from three FITS files.
 
-    Required arguments:
+    Parameters
+    ----------
 
-        *data*: [ string | tuple | list ]
-            If a string, this is the filename of an RGB FITS cube. If a tuple
-            or list, this should give the filename of three files to use for
-            the red, green, and blue channel.
+    data : str or tuple or list
+        If a string, this is the filename of an RGB FITS cube. If a tuple
+        or list, this should give the filename of three files to use for
+        the red, green, and blue channel.
 
-        *output*: [ string ]
-            The output filename. The image type (e.g. PNG, JPEG, TIFF, ...)
-            will be determined from the extension. Any image type supported by
-            the Python Imaging Library can be used.
+    output : str
+        The output filename. The image type (e.g. PNG, JPEG, TIFF, ...)
+        will be determined from the extension. Any image type supported by
+        the Python Imaging Library can be used.
 
-    Optional keyword arguments:
+    indices : tuple, optional
+        If data is the filename of a FITS cube, these indices are the
+        positions in the third dimension to use for red, green, and
+        blue respectively. The default is to use the first three
+        indices.
 
-        *indices*: [ tuple ]
-            If data is the filename of a FITS cube, these indices are the
-            positions in the third dimension to use for red, green, and
-            blue respectively. The default is to use the first three
-            indices.
+    vmin_r, vmin_g, vmin_b : float, optional
+        Minimum pixel value to use for the red, green, and blue channels.
+        If set to None for a given channel, the minimum pixel value for
+        that channel is determined using the corresponding pmin_x argument
+        (default).
 
-        *vmin_r*: [ None | float ]
+    vmax_r, vmax_g, vmax_b : float, optional
+        Maximum pixel value to use for the red, green, and blue channels.
+        If set to None for a given channel, the maximum pixel value for
+        that channel is determined using the corresponding pmax_x argument
+        (default).
 
-        *vmin_g*: [ None | float ]
+    pmin_r, pmin_r, pmin_g : float, optional
+        Percentile values used to determine for a given channel the
+        minimum pixel value to use for that channel if the corresponding
+        vmin_x is set to None. The default is 0.25% for all channels.
 
-        *vmin_b*: [ None | float ]
+    pmax_r, pmax_g, pmax_b : float, optional
+        Percentile values used to determine for a given channel the
+        maximum pixel value to use for that channel if the corresponding
+        vmax_x is set to None. The default is 99.75% for all channels.
 
-            Minimum pixel value to use for the red, green, and blue channels.
-            If set to None for a given channel, the minimum pixel value for
-            that channel is determined using the corresponding pmin_x argument
-            (default).
+    stretch_r, stretch_g, stretch_b : { 'linear', 'log', 'sqrt', 'arcsinh', 'power' }
+        The stretch function to use for the different channels.
 
-        *vmax_r*: [ None | float ]
+    vmid_r, vmid_g, vmid_b : float, optional
+        Baseline values used for the log and arcsinh stretches. If
+        set to None, this is set to zero for log stretches and to
+        vmin - (vmax - vmin) / 30. for arcsinh stretches
 
-        *vmax_g*: [ None | float ]
+    exponent_r, exponent_g, exponent_b : float, optional
+        If stretch_x is set to 'power', this is the exponent to use.
 
-        *vmax_b*: [ None | float ]
+    embed_avm_tags : bool, optional
+        Whether to embed AVM tags inside the image - this can only be done for
+        JPEG and PNG files, and only if PyAVM is installed.
+    '''
 
-            Maximum pixel value to use for the red, green, and blue channels.
-            If set to None for a given channel, the maximum pixel value for
-            that channel is determined using the corresponding pmax_x argument
-            (default).
-
-        *pmin_r*: [ float ]
-
-        *pmin_g*: [ float ]
-
-        *pmin_b*: [ float ]
-
-            Percentile values used to determine for a given channel the
-            minimum pixel value to use for that channel if the corresponding
-            vmin_x is set to None. The default is 0.25% for all channels.
-
-        *pmax_r*: [ float ]
-
-        *pmax_g*: [ float ]
-
-        *pmax_b*: [ float ]
-
-            Percentile values used to determine for a given channel the
-            maximum pixel value to use for that channel if the corresponding
-            vmax_x is set to None. The default is 99.75% for all channels.
-
-        *stretch_r*: [ 'linear' | 'log' | 'sqrt' | 'arcsinh' | 'power' ]
-
-        *stretch_g*: [ 'linear' | 'log' | 'sqrt' | 'arcsinh' | 'power' ]
-
-        *stretch_b*: [ 'linear' | 'log' | 'sqrt' | 'arcsinh' | 'power' ]
-
-            The stretch function to use for the different channels.
-
-        *vmid_r*: [ None | float ]
-
-        *vmid_g*: [ None | float ]
-
-        *vmid_b*: [ None | float ]
-
-            Baseline values used for the log and arcsinh stretches. If
-            set to None, this is set to zero for log stretches and to
-            vmin - (vmax - vmin) / 30. for arcsinh stretches
-
-        *exponent_r*: [ float ]
-
-        *exponent_g*: [ float ]
-
-        *exponent_b*: [ float ]
-
-            If stretch_x is set to 'power', this is the exponent to use.
-        '''
-
-    if not installed_pil:
-        raise Exception("The Python Imaging Library (PIL) is not installed but is required for this function")
+    try:
+        from PIL import Image
+    except ImportError:
+        try:
+            import Image
+        except ImportError:
+            raise ImportError("The Python Imaging Library (PIL) is required to make an RGB image")
 
     if isinstance(data, basestring):
 
-        image = pyfits.getdata(data)
+        image = fits.getdata(data)
         image_r = image[indices[0], :, :]
         image_g = image[indices[1], :, :]
         image_b = image[indices[2], :, :]
 
         # Read in header
-        header = pyfits.getheader(data)
+        header = fits.getheader(data)
 
         # Remove information about third dimension
         header['NAXIS'] = 2
@@ -195,17 +144,17 @@ def make_rgb_image(data, output, indices=(0, 1, 2), \
     elif (type(data) == list or type(data) == tuple) and len(data) == 3:
 
         filename_r, filename_g, filename_b = data
-        image_r = pyfits.getdata(filename_r)
-        image_g = pyfits.getdata(filename_g)
-        image_b = pyfits.getdata(filename_b)
+        image_r = fits.getdata(filename_r)
+        image_g = fits.getdata(filename_g)
+        image_b = fits.getdata(filename_b)
 
         # Read in header
-        header = pyfits.getheader(filename_r)
+        header = fits.getheader(filename_r)
 
     else:
         raise Exception("data should either be the filename of a FITS cube or a list/tuple of three images")
 
-    logger.info("Red:")
+    log.info("Red:")
     image_r = Image.fromarray(_data_stretch(image_r, \
                                             vmin=vmin_r, vmax=vmax_r, \
                                             pmin=pmin_r, pmax=pmax_r, \
@@ -213,7 +162,7 @@ def make_rgb_image(data, output, indices=(0, 1, 2), \
                                             vmid=vmid_r, \
                                             exponent=exponent_r))
 
-    logger.info("\nGreen:")
+    log.info("Green:")
     image_g = Image.fromarray(_data_stretch(image_g, \
                                             vmin=vmin_g, vmax=vmax_g, \
                                             pmin=pmin_g, pmax=pmax_g, \
@@ -221,7 +170,7 @@ def make_rgb_image(data, output, indices=(0, 1, 2), \
                                             vmid=vmid_g, \
                                             exponent=exponent_g))
 
-    logger.info("\nBlue:")
+    log.info("Blue:")
     image_b = Image.fromarray(_data_stretch(image_b, \
                                             vmin=vmin_b, vmax=vmax_b, \
                                             pmin=pmin_b, pmax=pmax_b, \
@@ -235,13 +184,24 @@ def make_rgb_image(data, output, indices=(0, 1, 2), \
     img.save(output)
 
     if embed_avm_tags:
-        if not avm_installed:
-            raise Exception("PyAVM needs to be installed in order to be able to embed AVM tags into the RGB image")
-        else:
-            avm = AVM(header)
-            avm.embed(output, output)
 
-    return
+        try:
+            import pyavm
+        except ImportError:
+            warnings.warn("PyAVM 0.9.1 or later is not installed, so AVM tags will not be embedded in RGB image")
+            return
+
+        if version.LooseVersion(pyavm.__version__) < version.LooseVersion('0.9.1'):
+            warnings.warn("PyAVM 0.9.1 or later is not installed, so AVM tags will not be embedded in RGB image")
+            return
+
+        from pyavm import AVM
+
+        if output.lower().endswith(('.jpg', '.jpeg', '.png')):
+            avm = AVM.from_header(header)
+            avm.embed(output, output)
+        else:
+            warnings.warn("AVM tags will not be embedded in RGB image, as only JPEG and PNG files are supported")
 
 
 def make_rgb_cube(files, output, north=False, system=None, equinox=None):
@@ -261,37 +221,40 @@ def make_rgb_cube(files, output, north=False, system=None, equinox=None):
     generated from the FITS cube (to provide the correct WCS information to
     FITSFigure).
 
-    Required arguments:
+    Parameters
+    ----------
 
-        *files* [ tuple | list ]
-            A list of the filenames of three FITS filename to reproject.
-            The order is red, green, blue.
+    files : tuple or list
+       A list of the filenames of three FITS filename to reproject.
+       The order is red, green, blue.
 
-        *output* [ string ]
-            The filename of the output RGB FITS cube.
+    output : str
+       The filename of the output RGB FITS cube.
 
-    Optional Keyword Arguments:
+    north : bool, optional
+       By default, the FITS header generated by Montage represents the
+       best fit to the images, often resulting in a slight rotation. If
+       you want north to be straight up in your final mosaic, you should
+       use this option.
 
-        *north* [ True | False ]
-            By default, the FITS header generated by Montage represents the
-            best fit to the images, often resulting in a slight rotation. If
-            you want north to be straight up in your final mosaic, you should
-            use this option.
+    system : str, optional
+       Specifies the system for the header (default is EQUJ).
+       Possible values are: EQUJ EQUB ECLJ ECLB GAL SGAL
 
-        *system* [ string ]
-            Specifies the system for the header (default is EQUJ).
-            Possible values are: EQUJ EQUB ECLJ ECLB GAL SGAL
-
-        *equinox* [ string ]
-            If a coordinate system is specified, the equinox can also be given
-            in the form YYYY. Default is J2000.
+    equinox : str, optional
+       If a coordinate system is specified, the equinox can also be given
+       in the form YYYY. Default is J2000.
     '''
 
     # Check whether the Python montage module is installed. The Python module
     # checks itself whether the Montage command-line tools are available, and
     # if they are not then importing the Python module will fail.
-    if not montage_installed:
-        raise Exception("Both the Montage command-line tools and the Python-montage module are required for this function")
+    try:
+        import montage_wrapper as montage
+    except ImportError:
+        raise Exception("Both the Montage command-line tools and the"
+                        " montage-wrapper Python module are required"
+                        " for this function")
 
     # Check that input files exist
     for f in files:
@@ -306,7 +269,6 @@ def make_rgb_cube(files, output, north=False, system=None, equinox=None):
 
     images_raw_tbl = '%s/images_raw.tbl' % work_dir
     header_hdr = '%s/header.hdr' % work_dir
-    header_py_hdr = '%s/header_py.hdr' % work_dir
 
     # Create raw and final directory in work directory
     os.mkdir(raw_dir)
@@ -320,13 +282,8 @@ def make_rgb_cube(files, output, north=False, system=None, equinox=None):
     montage.mImgtbl(raw_dir, images_raw_tbl, corners=True)
     montage.mMakeHdr(images_raw_tbl, header_hdr, north_aligned=north, system=system, equinox=equinox)
 
-    # Write out header without 'END'
-    contents = open(header_hdr).read()
-    open(header_py_hdr, 'wb').write(contents.replace('END\n', ''))
-
-    # Read header in with pyfits
-    header = pyfits.Header()
-    header.fromTxtFile(header_py_hdr, replace=True)
+    # Read header in with astropy.io.fits
+    header = fits.Header.fromtextfile(header_hdr)
 
     # Find image dimensions
     nx = int(header['NAXIS1'])
@@ -344,16 +301,14 @@ def make_rgb_cube(files, output, north=False, system=None, equinox=None):
                           header=header_hdr, exact_size=True, bitpix=-32)
 
         # Read in and add to datacube
-        image_cube[i, :, :] = pyfits.getdata('%s/image_%i.fits' % (final_dir, i))
+        image_cube[i, :, :] = fits.getdata('%s/image_%i.fits' % (final_dir, i))
 
     # Write out final cube
-    pyfits.writeto(output, image_cube, header, clobber=True)
+    fits.writeto(output, image_cube, header, clobber=True)
 
     # Write out collapsed version of cube
-    pyfits.writeto(output.replace('.fits', '_2d.fits'), \
+    fits.writeto(output.replace('.fits', '_2d.fits'), \
                    np.mean(image_cube, axis=0), header, clobber=True)
 
     # Remove work directory
     shutil.rmtree(work_dir)
-
-    return
